@@ -4,20 +4,19 @@
  *
  * Copyright (C) 2009 - Jesse van den Kieboom
  *
- * gtksourceview is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * This library is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Library General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with gtksourceview; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Library General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "gtksourcecompletionwordsbuffer.h"
@@ -605,7 +604,11 @@ remove_and_rescan (GtkSourceCompletionWordsBuffer *buffer,
 		else if (gtk_text_iter_compare (&startc, &region_end) < 0)
 		{
 			startc = region_end;
-			gtk_text_iter_forward_line (&startc);
+
+			if (!gtk_text_iter_forward_line (&startc))
+			{
+				return;
+			}
 		}
 
 		if (gtk_text_iter_compare (&startc, &endc) > 0)
