@@ -2,7 +2,7 @@
  * gtksourcecompletionitem.c
  * This file is part of gtksourcecompletion
  *
- * Copyright (C) 2009 - Jesse van den Kieboom
+ * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
  *
  * gtksourceview is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -54,22 +54,22 @@ G_DEFINE_TYPE_WITH_CODE (GtkSourceCompletionItem,
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SOURCE_COMPLETION_PROPOSAL,
 			 			gtk_source_completion_proposal_iface_init))
 
-static const gchar *
+static gchar *
 gtk_source_completion_proposal_get_label_impl (GtkSourceCompletionProposal *self)
 {
-	return GTK_SOURCE_COMPLETION_ITEM (self)->priv->label;
+	return g_strdup (GTK_SOURCE_COMPLETION_ITEM (self)->priv->label);
 }
 
-static const gchar *
+static gchar *
 gtk_source_completion_proposal_get_markup_impl (GtkSourceCompletionProposal *self)
 {
-	return GTK_SOURCE_COMPLETION_ITEM (self)->priv->markup;
+	return g_strdup (GTK_SOURCE_COMPLETION_ITEM (self)->priv->markup);
 }
 
-static const gchar *
+static gchar *
 gtk_source_completion_proposal_get_text_impl (GtkSourceCompletionProposal *self)
 {
-	return GTK_SOURCE_COMPLETION_ITEM (self)->priv->text;
+	return g_strdup (GTK_SOURCE_COMPLETION_ITEM (self)->priv->text);
 }
 
 static GdkPixbuf *
@@ -78,10 +78,10 @@ gtk_source_completion_proposal_get_icon_impl (GtkSourceCompletionProposal *self)
 	return GTK_SOURCE_COMPLETION_ITEM (self)->priv->icon;
 }
 
-static const gchar *
+static gchar *
 gtk_source_completion_proposal_get_info_impl (GtkSourceCompletionProposal *self)
 {
-	return GTK_SOURCE_COMPLETION_ITEM (self)->priv->info;
+	return g_strdup (GTK_SOURCE_COMPLETION_ITEM (self)->priv->info);
 }
 
 static void
@@ -283,7 +283,7 @@ gtk_source_completion_item_class_init (GtkSourceCompletionItemClass *klass)
 							      NULL,
 							      G_PARAM_READWRITE));
 
-	g_type_class_add_private (object_class, sizeof(GtkSourceCompletionItemPrivate));
+	g_type_class_add_private (object_class, sizeof (GtkSourceCompletionItemPrivate));
 }
 
 static void
@@ -294,17 +294,16 @@ gtk_source_completion_item_init (GtkSourceCompletionItem *self)
 
 /** 
  * gtk_source_completion_item_new:
- * @label: The item label
- * @text: The item text
- * @icon: The item icon
- * @info: The item extra information
+ * @label: The item label.
+ * @text: The item text.
+ * @icon: (allow-none): The item icon.
+ * @info: (allow-none): The item extra information.
  *
  * Create a new #GtkSourceCompletionItem with label @label, icon @icon and 
  * extra information @info. Both @icon and @info can be %NULL in which case 
  * there will be no icon shown and no extra information available.
  *
- * Returns: The new #GtkSourceCompletionItem.
- *
+ * Returns: a new #GtkSourceCompletionItem.
  */
 GtkSourceCompletionItem *
 gtk_source_completion_item_new (const gchar *label,
@@ -322,17 +321,16 @@ gtk_source_completion_item_new (const gchar *label,
 
 /** 
  * gtk_source_completion_item_new_with_markup:
- * @markup: The item markup label
- * @text: The item text
- * @icon: The item icon
- * @info: The item extra information
+ * @markup: The item markup label.
+ * @text: The item text.
+ * @icon: (allow-none): The item icon.
+ * @info: (allow-none): The item extra information.
  *
  * Create a new #GtkSourceCompletionItem with markup label @markup, icon 
  * @icon and extra information @info. Both @icon and @info can be %NULL in 
  * which case there will be no icon shown and no extra information available.
  *
- * Returns: The new #GtkSourceCompletionItem.
- *
+ * Returns: a new #GtkSourceCompletionItem.
  */
 GtkSourceCompletionItem *
 gtk_source_completion_item_new_with_markup (const gchar *markup,
@@ -350,16 +348,15 @@ gtk_source_completion_item_new_with_markup (const gchar *markup,
 
 /** 
  * gtk_source_completion_item_new_from_stock:
- * @label: The item label
- * @text: The item text
- * @stock: The stock icon
- * @info: The item extra information
+ * @label: (allow-none): The item label.
+ * @text: The item text.
+ * @stock: The stock icon.
+ * @info: (allow-none): The item extra information.
  *
  * Creates a new #GtkSourceCompletionItem from a stock item. If @label is %NULL, 
  * the stock label will be used.
  *
- * Returns: the newly constructed #GtkSourceCompletionItem.
- *
+ * Returns: a new #GtkSourceCompletionItem.
  */
 GtkSourceCompletionItem *
 gtk_source_completion_item_new_from_stock (const gchar *label,
